
package com.ibm.jvm;

/*
 * Licensed Materials - Property of IBM,
 *     Copyright IBM Corp. 2008, 2010  All Rights Reserved
 */

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * The Debuggable annotation applies to either classes or methods and provides
 * a hint to the VM that decorated entities must remain debuggable.  This facility
 * is intended for use by languages implemented in Java where portions of the program
 * must support debugging (e.g. breakpoints, variable access) but where whole-program
 * optimization is critical.
 */

// Ensure that Debuggable annotations are visible at runtime
@Retention(RetentionPolicy.RUNTIME)

// Constrain Debuggable annotations to types and methods
@Target({ElementType.TYPE, ElementType.METHOD})

public @interface Debuggable {

}
